==> openapi-facade-0.0.4-20220425.065536-6-sources.jar: com/bizvane/openapifacade/enums/ResponseEnum.java <==
package com.bizvane.openapifacade.enums;
/*
 * Created by JiangWenjian on 2019-06-20.
 */

/**
 * @author jiangwenjian
 * @version 0.0.1
 * @since 0.0.1 2019-06-20
 */
public enum  ResponseEnum {

    SUCCESS(0, "操作成功！"),
    FAILED(-1, "操作失败！"),
    PARAM_FAILED_VALIDATION(100,"请求参数不通过"),
    OPERATE_FAILED_DATA_NOT_EXISTS(101, "查询数据不存在！"),
    OPERATE_FAILED_ADD_ERROR(102, "新增数据失败！"),
    OPERATE_FAILED_UPDATE_ERROR(103, "更新数据失败！"),
    OPERATE_FAILED_FILE_NOT_EXISTS(104, "操作失败，文件不存在！"),
    OPERATE_FAILED_FILE_UPLOAD_ERROR(105, "操作失败，文件上传错误！"),
    USER_LOGIN_FAILED_VALIDATECODE_NOT_EXISTS(106, "验证码不存在！"),
    USER_LOGIN_FAILED_VALIDATECODE_ERROR(107, "验证码错误！"),
    USER_LOGIN_SMS_CODE_OVERTIME(108, "短信验证码已过期！"),
    USER_LOGIN_FAILED_USERID_NOT_EXISTS(109, "登录失败，用户名不存在！"),
    USER_BIND_THIRD_LOGIN_ERROR(110, "登录失败，用户被禁用！"),
    USER_LOGIN_FAILED_USER_DISABLE(111, "登录失败，密码错误！"),
    USER_UPDATE_ERROR(112, "修改用户失败！"),
    USER_MIBILE_NOT_EXIST(113, "该手机号不存在！"),
    NETWORK_ERROR(114, "网络异常！"),
    SYSTEM_ERROR(115, "系统内部错误！"),
    USER_MIBILE_EXIST(118, "该手机号已存在！"),
    STAFF_EXIST_STORE_NOT_EXISTS(119, "传导购参数时，必须要传店铺参数！"),
    MEMBERINFO_NOT_EXISTS(120,"会员数据不存在"),
    MODEL_FAILED_VALIDATION(500, "数据验证不通过"),
    SING_FAILED_VALIDATION(501,"页签验证不通过");

    private int code;
    private String message;

    private ResponseEnum(int code, String message) {
        this.code = code;
        this.message = message;
    }

    public int getCode() {
        return this.code;
    }

    public String getMessage() {
        return this.message;
    }

}

==> openapi-facade-20241029-20250616.025308-7-sources.jar: com/bizvane/openapifacade/enums/ResponseEnum.java <==
package com.bizvane.openapifacade.enums;
/*
 * Created by JiangWenjian on 2019-06-20.
 */

/**
 * @author jiangwenjian
 * @version 0.0.1
 * @since 0.0.1 2019-06-20
 */
public enum  ResponseEnum {

    SUCCESS(0, "操作成功！"),
    FAILED(-1, "操作失败！"),
    PARAM_FAILED_VALIDATION(100,"请求参数不通过"),
    OPERATE_FAILED_DATA_NOT_EXISTS(101, "查询数据不存在！"),
    OPERATE_FAILED_ADD_ERROR(102, "新增数据失败！"),
    OPERATE_FAILED_UPDATE_ERROR(103, "更新数据失败！"),
    OPERATE_FAILED_FILE_NOT_EXISTS(104, "操作失败，文件不存在！"),
    OPERATE_FAILED_FILE_UPLOAD_ERROR(105, "操作失败，文件上传错误！"),
    USER_LOGIN_FAILED_VALIDATECODE_NOT_EXISTS(106, "验证码不存在！"),
    USER_LOGIN_FAILED_VALIDATECODE_ERROR(107, "验证码错误！"),
    USER_LOGIN_SMS_CODE_OVERTIME(108, "短信验证码已过期！"),
    USER_LOGIN_FAILED_USERID_NOT_EXISTS(109, "登录失败，用户名不存在！"),
    USER_BIND_THIRD_LOGIN_ERROR(110, "登录失败，用户被禁用！"),
    USER_LOGIN_FAILED_USER_DISABLE(111, "登录失败，密码错误！"),
    USER_UPDATE_ERROR(112, "修改用户失败！"),
    USER_MIBILE_NOT_EXIST(113, "该手机号不存在！"),
    NETWORK_ERROR(114, "网络异常！"),
    SYSTEM_ERROR(115, "系统内部错误！"),
    USER_MIBILE_EXIST(118, "该手机号已存在！"),
    STAFF_EXIST_STORE_NOT_EXISTS(119, "传导购参数时，必须要传店铺参数！"),
    MODEL_FAILED_VALIDATION(500, "数据验证不通过"),
    BRAND_CODE_NOT_NULL(550, "品牌code不能为空"),
    COUPON_CODE_NOT_NULL(560, "券code不能为空"),
    SING_FAILED_VALIDATION(501,"页签验证不通过");

    private int code;
    private String message;

    private ResponseEnum(int code, String message) {
        this.code = code;
        this.message = message;
    }

    public int getCode() {
        return this.code;
    }

    public String getMessage() {
        return this.message;
    }

}
